#!/bin/bash

if [ "$1" == "" ]
then
  echo "usage: make-binary-distros.sh <version>"
  exit 1
fi

version=$1
source=../../branches/$version
export=../../export
ports=../../ports
firmware=./lib/firmware/qhy
distroName=$export/oaCapture-$version
top=oacapture-$version

if [ ! -d $source ]
then
  echo "$source does not exist"
  exit 2
fi

here=`pwd`
for distro in old-32bit old-64bit recent-32bit recent-64bit raspbian
do
  topdir=$export/$top-$distro
  mkdir -p $topdir
  if [ -d $topdir/lib -o -d $topdir/bin ]
  then
    echo $topdir/lib or $topdir/bin appears to exist already
    exit 1
  fi

  mkdir -p $topdir/bin $topdir/lib/firmware/qhy
  case $distro in
    old-32bit)
      cp $ports/mint-13-32-bit/* $topdir/bin
      ;;
    recent-32bit)
      cp $ports/fedora-18-32-bit/* $topdir/bin
      ;;
    old-64bit)
      cp $ports/mint-13-64-bit/* $topdir/bin
      ;;
    recent-64bit)
      cp $ports/fedora-18-64-bit/* $topdir/bin
      ;;
    raspbian)
      cp $ports/raspbian/* $topdir/bin
      ;;
    *)
      echo "unrecognised distribution $distro"
      exit 2
      ;;
  esac

  if [ -f $topdir/bin/oacapture.static ]; then
    mv $topdir/bin/oacapture.static $topdir/bin/oacapture
  fi
  cp $firmware/QHY5.HEX $firmware/QHY5LOADER.HEX $topdir/lib/firmware/qhy
  cp $firmware/QHY5II.HEX $topdir/lib/firmware/qhy
  cp $firmware/QHY6.HEX $topdir/lib/firmware/qhy
  cp $firmware/QHY6OLD.HEX $topdir/lib/firmware/qhy

  cp -r ./udev $topdir
  rm $topdir/udev/Makefile
  cp ./bin/install-binaries.sh $topdir
  cp ./docs/README.txt $topdir
  cd $export
  tar jcf ./$top-$distro.tar.bz2 ./$top-$distro
  cd $here
done
