/*****************************************************************************
 *
 * AtikSerialstate.h -- Atik serial camera state header
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_ATIK_SERIAL_STATE_H
#define OA_ATIK_SERIAL_STATE_H

#include <sys/types.h>
#include <pthread.h>

struct atikSerialbuffer {
  void   *start;
  size_t length;
};


typedef struct AtikSerial_STATE {
  int                   initialised;
  int                   fd;
  unsigned long         index;
  libusb_context*       usbContext;
  libusb_device_handle* usbHandle;
  void*			ftdiContext;
  int                   cameraType;
  pthread_mutex_t       serialMutex;
  char	                devicePath[ PATH_MAX+1];
  unsigned int          maxResolutionX;
  unsigned int          maxResolutionY;
  unsigned int          cameraFlags;
  unsigned int          pixelSizeX;
  unsigned int          pixelSizeY;
  unsigned int          maxBinningX;
  unsigned int          maxBinningY;
  unsigned int          wellDepth;
  // FIX ME -- ought to do this dynamically
  FRAMESIZE             resolutions[OA_MAX_RESOLUTIONS+1];
  unsigned int          currentExposure;
  unsigned int          captureLength;
  unsigned int          imageBufferLength;
  unsigned char*        xferBuffer;
  int                   captureThreadStarted;
  int                   captureThreadExit;
  pthread_mutex_t       captureMutex;
  pthread_cond_t        frameAvailable;
  struct atikSerialbuffer* buffers;
  int                   configuredBuffers;
  unsigned int		colour;
  unsigned int		binMode;
  unsigned int		horizontalBinMode;
  unsigned int		verticalBinMode;
  unsigned int          xSize;
  unsigned int          ySize;
  pthread_t             captureThread;
  int                   haveDataToRead;
  int                   nextBufferToRead;
  uint32_t		ccdReadFlags;
  unsigned int		hardwareType;
  unsigned int		haveFIFO;
  unsigned int		droppedFrames;
/*
  FRAMESIZE             binMode2Resolutions[OA_MAX_RESOLUTIONS+1];
*/
} AtikSerial_STATE;

#endif	/* OA_ATIK_SERIAL_STATE_H */
