/*****************************************************************************
 *
 * SXstate.h -- Starlight Xpress state header
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_SX_STATE_H
#define OA_SX_STATE_H

#include <sys/types.h>
#include <libusb-1.0/libusb.h>
#include <pthread.h>

struct SXbuffer {
  void   *start;
  size_t length;
};


typedef struct SX_STATE {
  int                   initialised;
  unsigned long         index;
  libusb_context*       usbContext;
  libusb_device_handle* usbHandle;
  int                   cameraType;
  uint64_t		droppedFrames;
  int                   captureThreadStarted;
  int                   captureThreadExit;
  pthread_t             captureThread;
  pthread_mutex_t       captureMutex;
  pthread_mutex_t       usbMutex;
  pthread_cond_t        frameAvailable;
  uint32_t		horizontalFrontPorch;
  uint32_t		horizontalBackPorch;
  uint32_t		verticalFrontPorch;
  uint32_t		verticalBackPorch;
  uint32_t		colourMatrix;
  uint32_t		bitDepth;
  uint32_t              maxResolutionX;
  uint32_t              maxResolutionY;
  unsigned int          isColour;
  unsigned int          isInterlaced;
  int                   videoGrey16;
  int                   videoGrey;
  unsigned int          videoCurrent;
  unsigned int          xSize;
  unsigned int          ySize;
  FRAMESIZE             resolutions[OA_MAX_RESOLUTIONS+1];
  FRAMESIZE             binMode2Resolutions[OA_MAX_RESOLUTIONS+1];
  unsigned int          currentExposure;
  int                   configuredBuffers;
  unsigned int          captureLength;
  struct SXbuffer*	buffers;
  unsigned char*        xferBuffer;
  int                   haveDataToRead;
  int                   nextBufferToRead;
  unsigned int          imageBufferLength;
  unsigned int          bytesPerPixel;
  unsigned int          requestedBinMode;
  unsigned int          binMode;
} SX_STATE;

#endif	/* OA_SX_STATE_H */
