/*****************************************************************************
 *
 * UVCstate.h -- UVC camera state header
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_UVC_STATE_H
#define OA_UVC_STATE_H

#define UVC_BUFFERS 3

#include <sys/types.h>
#include <libuvc/libuvc.h>

struct UVCbuffer {
  void   *start;
  size_t length;
};

typedef struct UVC_STATE {
  int                   initialised;
  unsigned long         index;
  int			unitId;
  uvc_context_t*        uvcContext;
  uvc_device_handle_t*  uvcHandle;
  uvc_stream_ctrl_t	streamControl;
  int			haveWhiteBalanceManual;
  int			autoWhiteBalanceOff;
  int                   videoGrey;
  int                   videoRaw;
  int                   videoStreamed;
  const uvc_format_desc_t* videoCurrent;
  unsigned int          isColour;
  unsigned int          maxResolutionX;
  unsigned int          maxResolutionY;
  int                   configuredBuffers;
  unsigned int          imageBufferLength;
  int                   lastUsedBuffer;
  struct UVCbuffer*     buffers;
  unsigned long		frameInterval;
  pthread_mutex_t       captureMutex;
  pthread_cond_t        frameAvailable;
  int                   haveDataToRead;
  int                   nextBufferToRead;
  unsigned int          componentBalance;
  // FIX ME -- ought to do this dynamically
  FRAMESIZE		resolutions[OA_MAX_RESOLUTIONS+1];
  // FIX ME -- only works for discrete rates?
  FRAMERATE      	framerates[OA_MAX_FRAMERATES+1];
/*
  int                   fd;
  int                   cameraType;
  int                   videoYUV420;
  int                   videoRGB24;
  int                   videoYUYV;
  int                   videoGrey16;
  int                   xSize;
  int                   ySize;
  unsigned int          xferBufferLength;
  unsigned int          captureLength;
  unsigned int          captureHeight;
  unsigned int          frameSize;
  unsigned char*        xferBuffer;
  int                   captureThreadStarted;
  int                   captureThreadExit;
  unsigned int          frameTime;
  pthread_t             captureThread;
  pthread_mutex_t       usbMutex;
  unsigned int          exposureTime;
  unsigned int          transferTime;
  unsigned int          requestedExposure;
  unsigned int          xOffset;
  unsigned int          yOffset;
  unsigned int          doSetParameters;
  unsigned int		longExposureMode;
  unsigned long		droppedFrames;
  unsigned int		hasFirmware;
  unsigned int		firmwareLoaded;
*/
} UVC_STATE;

#endif	/* OA_UVC_STATE_H */
