/*****************************************************************************
 *
 * SXgetState.c -- state querying for Starlight Xpress cameras
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>
#include <openastro/camera.h>

#include "SXoacam.h"

#define	cameraState		camera->_sx


int
oaSXCameraGetControlRange ( oaCamera* camera, int control, int64_t* min,
    int64_t* max, int64_t* step, int64_t* def )
{
  if ( !camera->controls[ control ] ) {
    return -OA_ERR_INVALID_CONTROL;
  }

  *min = camera->min[ control ];
  *max = camera->max[ control ];
  *step = camera->step[ control ];
  *def = camera->def[ control ];
  return 0;
}


const FRAMESIZE*
oaSXCameraGetFrameSizes ( oaCamera* camera )
{
  switch ( cameraState.requestedBinMode ) {
    case OA_BIN_MODE_NONE:
      return cameraState.resolutions;
      break;
    case OA_BIN_MODE_2x2:
      return cameraState.binMode2Resolutions;
      break;
/*
    case OA_BIN_MODE_3x3:
      return cameraState.binMode3Resolutions;
      break;
    case OA_BIN_MODE_4x4:
      return cameraState.binMode4Resolutions;
      break;
*/
  }
  fprintf ( stderr, "oaSXCameraGetFrameSizes: unknown bin mode %d\n",
      cameraState.binMode );
  return 0;
}


const char*
oaSXCameraGetName ( oaCamera* camera )
{
  return camera->deviceName;
}


int
oaSXCameraGetFramePixelFormat ( oaCamera *camera, int depth )
{
  if ( depth <= 0 ) {
    return cameraState.videoCurrent;
  } else {
    if ( depth > 8 ) {
      return OA_PIX_FMT_GRBG16LE;
    }
  }
  return OA_PIX_FMT_GREY8;
}
