/*****************************************************************************
 *
 * ZWASIcapture.c -- capture functions for ZW ASI cameras
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>
#include <openastro/camera.h>

#include "ZWASIoacam.h"
#include <ASICamera.h>
#include "oacamprivate.h"

#define cameraState             camera->_zwasi

int
oaZWASICameraReadFrame ( oaCamera* camera, void** bufferPtr )
{
  int			ret;

  oacamDebugMsg ( DEBUG_CAM_CMD, "ZWASI: command: %s()\n", __FUNCTION__ );

  cameraState.bufferInUse = 0;
  if ( cameraState.lastUsedBuffer < 0 ) {
    cameraState.lastUsedBuffer = 0;
  }
  *bufferPtr = 0;
  if (( ret = getImageData (
      cameraState.buffers[ cameraState.lastUsedBuffer].start,
//    cameraState.imageBufferLength, -1 ))) {
      cameraState.imageBufferLength, cameraState.frameTime ))) {
    *bufferPtr = cameraState.buffers[ cameraState.lastUsedBuffer].start;
    cameraState.bufferInUse = 1;
    ret = cameraState.imageBufferLength;
  }
  oacamDebugMsg ( DEBUG_CAM_CMD, "ZWASI: command: %s() returns %d\n",
      __FUNCTION__, ret );
  return ret;
}


int
oaZWASICameraStartReadFrame ( oaCamera* camera, unsigned int frameTime )
{
  oacamDebugMsg ( DEBUG_CAM_CMD, "ZWASI: command: %s ( %d )\n",
      __FUNCTION__, frameTime );

  // frame time is passed in as usec, but we will use it as msec.
  cameraState.frameTime = frameTime / 1000;
  return OA_ERR_NONE;
}


int
oaZWASICameraFinishReadFrame ( oaCamera* camera )
{
  oacamDebugMsg ( DEBUG_CAM_CMD, "ZWASI: command: %s()\n", __FUNCTION__ );

  if ( cameraState.bufferInUse ) {
    cameraState.bufferInUse = 0;
    cameraState.lastUsedBuffer = ( cameraState.lastUsedBuffer + 1 ) %
        cameraState.configuredBuffers;
  }
  return OA_ERR_NONE;
}
