/*****************************************************************************
 *
 * atikSerialIO-udev.c -- Atik serial camera IO routines (libudev)
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>

#include <errno.h>
#include <libftdi1/ftdi.h>
#include <openastro/camera.h>

#include "atikSerialoacam.h"


int
_atikSerialCamWrite ( struct ftdi_context* ftdiContext,
    const unsigned char* buffer, int len )
{
  if ( ftdi_usb_purge_buffers ( ftdiContext )) {
    fprintf ( stderr, "FTDI buffer purge failed\n" );
    return -1;
  }

  if ( ftdi_write_data ( ftdiContext, buffer, len ) != len ) {
    return -1;
  }
  return 0;
}


int
_atikSerialCamRead ( struct ftdi_context* ftdiContext,
    unsigned char* buffer, int maxlen )
{
  unsigned char *p = (unsigned char*) buffer;
  int done = 0, len = 0, tries, bytes;

  // libftdi1 doesn't have a blocking read, so for the time being we
  // loop for up to ten seconds (actually 100 tries) attempting to read
  // from the target device with a 100ms delay between each attempt.  Any
  // valid read resets the loop timer.
  // It's a bit scabby, but it appears to do the job for the time being.
  //
  // FIX ME
  // Should really replace this with select() or similar
  do {
    tries = 0;
    do {
      if (!( bytes = ftdi_read_data ( ftdiContext, p, 1 ))) {
        tries++;
        usleep ( 100000 );
      }
    } while ( !bytes && tries < 100 );
    if ( bytes != 1 ) {
      return -1;
    }
    len++;
    p++;
  } while ( !done && len < maxlen );

  return len;
}


int
_atikSerialCamReadToZero ( struct ftdi_context* ftdiContext,
    unsigned char* buffer )
{
  unsigned char *p = (unsigned char*) buffer;
  int done = 0, len = 1, tries, bytes;

  // libftdi1 doesn't have a blocking read, so for the time being we
  // loop for up to ten seconds (actually 100 tries) attempting to read
  // from the target device with a 100ms delay between each attempt.  Any
  // valid read resets the loop timer.
  // It's a bit scabby, but it appears to do the job for the time being.
  //
  // FIX ME
  // Should really replace this with select() or similar
  do {
    tries = 0;
    do {
      if (!( bytes = ftdi_read_data ( ftdiContext, p, 1 ))) {
        tries++;
        usleep ( 100000 );
      }
    } while ( !bytes && tries < 100 );
    if ( bytes != 1 ) {
      return -1;
    }
    if ( !*p++ ) {
      done = 1;
    }
    len++;
  } while ( !done );

  return len - 1;
}


int
_atikSerialCamReadBlock ( struct ftdi_context* ftdiContext,
    unsigned char* buffer, int len )
{
  return ( _atikSerialCamRead ( ftdiContext, buffer, len ));
}

