/*****************************************************************************
 *
 * atikSerialgetState.c -- state querying for Atik serial cameras
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>
#include <openastro/camera.h>

#include "atikSerialoacam.h"

#define	cameraState		camera->_atikSerial


int
oaAtikSerialCameraGetControlRange ( oaCamera* camera, int control,
    int64_t* min, int64_t* max, int64_t* step, int64_t* def )
{
  if ( !camera->controls[ control ] ) {
    return -OA_ERR_INVALID_CONTROL;
  }

  *min = camera->min[ control ];
  *max = camera->max[ control ];
  *step = camera->step[ control ];
  *def = camera->def[ control ];
  return 0;
}


const FRAMESIZE*
oaAtikSerialCameraGetFrameSizes ( oaCamera* camera )
{
  switch ( cameraState.binMode ) {
    case OA_BIN_MODE_NONE:
      return cameraState.resolutions;
      break;
/*
    case OA_BIN_MODE_2x2:
      return cameraState.binMode2Resolutions;
      break;
    case OA_BIN_MODE_3x3:
      return cameraState.binMode3Resolutions;
      break;
    case OA_BIN_MODE_4x4:
      return cameraState.binMode4Resolutions;
      break;
*/
  }
  fprintf ( stderr, "oaAtikSerialCameraGetFrameSizes: unknown bin mode %d\n",
      cameraState.binMode );
  return 0;
}


const char*
oaAtikSerialCameraGetName ( oaCamera* camera )
{
  return camera->deviceName;
}


int
oaAtikSerialCameraGetFramePixelFormat ( oaCamera *camera, int depth )
{
  // bit depth is irrelevant -- there can be only one
  if ( cameraState.colour ) {
    return OA_PIX_FMT_RGGB16LE;
  }
  return OA_PIX_FMT_GREY16LE;
}
