/*****************************************************************************
 *
 * sxControl.c -- Starlight Xpress filter wheel control functions
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>

#include <errno.h>
#include <openastro/filterwheel.h>

#include "sxfw.h"
#include "oafwprivate.h"
#include "unimplemented.h"

#define	wheelState		wheel->_sx


int
oaSXMoveTo ( oaFilterWheel* wheel, int slot, int nodelay )
{
  char buffer[2];
  int numRead, actualSlot;

  if ( nodelay ) {
    fprintf ( stderr, "%s: ignoring nodelay\n", __FUNCTION__ );
  }

  pthread_mutex_lock ( &wheelState.usbMutex );

  buffer[0] = slot;
  buffer[1] = 0;
  if ( _sxWheelWrite ( wheel, buffer, 2 ) != 2 ) {
    fprintf ( stderr, "%s: write error on move command\n",
      __FUNCTION__ );
    pthread_mutex_unlock ( &wheelState.usbMutex );
    return -1;
  }
  numRead = _sxWheelRead ( wheel, buffer, 2 );
  if ( numRead != 2 ) {
    pthread_mutex_unlock ( &wheelState.usbMutex );
    return -1;
  }

  do {
    sleep ( 1 );

    buffer[0] = 0;
    buffer[1] = 0;
    if ( _sxWheelWrite ( wheel, buffer, 2 ) != 2 ) {
      fprintf ( stderr, "%s: write error on move command 2\n",
        __FUNCTION__ );
      pthread_mutex_unlock ( &wheelState.usbMutex );
      return -1;
    }
    numRead = _sxWheelRead ( wheel, buffer, 2 );
    if ( numRead != 2 ) {
      pthread_mutex_unlock ( &wheelState.usbMutex );
      return -1;
    }
  } while ( !buffer[0] );

  pthread_mutex_unlock ( &wheelState.usbMutex );

  actualSlot = buffer[0];
  if ( actualSlot != slot ) {
    fprintf ( stderr, "%s: requested slot %d, got slot %d\n",
        __FUNCTION__, slot, actualSlot );
    return -1;
  }
  return 0;
}


int
oaSXNumSlots ( oaFilterWheel* wheel )
{
  return wheelState.numSlots;
}
