/*****************************************************************************
 *
 * unimplemented.c -- catch-all for unimplemented filter wheel functions
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>

#include <openastro/filterwheel.h>

#include "oafwprivate.h"
#include "unimplemented.h"


static oaFilterWheel*
_initFilterWheel ( oaFilterWheelDevice* device )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      device->deviceName );
  return 0;
}


static int
_closeFilterWheel ( oaFilterWheel* wheel )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static const char*
_getName ( oaFilterWheel* wheel )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return "";
}


static int
_moveForward ( oaFilterWheel* wheel, int n, int r )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static int
_moveBackward ( oaFilterWheel* wheel, int n, int r )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static int
_moveTo ( oaFilterWheel* wheel, int n, int r )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static int
_warmReset ( oaFilterWheel* wheel, int r )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static int
_coldReset ( oaFilterWheel* wheel, int r )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static int
_numSlots ( oaFilterWheel* wheel )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static int
_getSpeed ( oaFilterWheel* wheel, unsigned int* speed )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


static int
_setSpeed ( oaFilterWheel* wheel, unsigned int speed, int nodelay )
{
  fprintf ( stderr, "%s not implemented for %s\n", __FUNCTION__,
      wheel->deviceName );
  return -OA_ERR_UNIMPLEMENTED;
}


void
_oaInitFilterWheelDeviceFunctionPointers ( oaFilterWheelDevice* device )
{
  device->initFilterWheel = _initFilterWheel;
}


void
_oaInitFilterWheelFunctionPointers ( oaFilterWheel* wheel )
{
  wheel->funcs.initWheel = _initFilterWheel;
  wheel->funcs.closeWheel = _closeFilterWheel;
  wheel->funcs.warmReset = _warmReset;
  wheel->funcs.coldReset = _coldReset;

  wheel->funcs.getName = _getName;

  wheel->funcs.moveForward = _moveForward;
  wheel->funcs.moveBackward = _moveBackward;
  wheel->funcs.moveTo = _moveTo;

  wheel->funcs.numSlots = _numSlots;
  wheel->funcs.getSpeed = _getSpeed;
  wheel->funcs.setSpeed = _setSpeed;
}
